@@ -1,5 +1,5 @@
 package App::gimpgitbuild::API::GitBuild;
-$App::gimpgitbuild::API::GitBuild::VERSION = '0.2.1';
+$App::gimpgitbuild::API::GitBuild::VERSION = '0.4.0';
 use strict;
 use warnings;
 use 5.014;
@@ -17,7 +17,8 @@ sub _build_home_dir
 sub _build_install_base_dir
 {
     my $self = shift;
-    return $self->home_dir . "/apps/graphics";
+    return $ENV{GIMPGITBUILD__BASE_INSTALL_DIR}
+        // ( $self->home_dir . "/apps/graphics" );
 }
 
 sub mypaint_p
@@ -32,12 +33,26 @@ sub babl_p
     return $self->install_base_dir . "/babl";
 }
 
+sub gimp_p
+{
+    my $self = shift;
+    return $self->install_base_dir . "/gimp-devel";
+}
+
 sub gegl_p
 {
     my $self = shift;
     return $self->install_base_dir . "/gegl";
 }
 
+sub base_git_clones_dir
+{
+    my $self = shift;
+
+    return $ENV{GIMPGITBUILD__BASE_CLONES_DIR}
+        // ( $self->home_dir . "/Download/unpack/graphics/gimp" );
+}
+
 sub new_env
 {
     my $self            = shift;
@@ -77,7 +92,7 @@ App::gimpgitbuild::API::GitBuild - common API
 
 =head1 VERSION
 
-version 0.2.1
+version 0.4.0
 
 =head1 METHODS
 
@@ -89,6 +104,10 @@ The BABL install prefix.
 
 The GEGL install prefix.
 
+=head2 gimp_p
+
+The GIMP install prefix.
+
 =head2 mypaint_p
 
 The libmypaint install prefix.
@@ -97,6 +116,17 @@ The libmypaint install prefix.
 
 Returns a hash reference of new environment variables to override.
 
+=head2 install_base_dir
+
+Can be overrided by setting the C<GIMPGITBUILD__BASE_INSTALL_DIR> environment
+variable.
+
+=head2 base_git_clones_dir
+
+The base filesystem directory path for the git repository clones.
+Can be overrided by setting the C<GIMPGITBUILD__BASE_CLONES_DIR> environment
+variable.
+
 =for :stopwords cpan testmatrix url bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
 
 =head1 SUPPORT
